@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::ModuleBuildTiny;
-$Dist::Zilla::Plugin::ModuleBuildTiny::VERSION = '0.018';
+$Dist::Zilla::Plugin::ModuleBuildTiny::VERSION = '0.019';
 use 5.020;
 
 use Moose;
@@ -83,6 +83,9 @@ has version => (
 		elsif (-e 'include/' or any { $_->name =~ /^src\/.*\.c$/} $self->zilla->files->@*) {
 			return '0.044';
 		}
+		elsif (-e 'module-share') {
+			return '0.044';
+		}
 		elsif ($self->has_pl) {
 			return '0.039';
 		}
@@ -231,10 +234,13 @@ sub gather_files($self) {
 }
 
 sub setup_installer($self) {
-	confess 'Module::Build::Tiny is currently incompatible with dynamic_config' if $self->zilla->distmeta->{dynamic_config};
-
 	for my $map (map { $_->share_dir_map } $self->zilla->plugins_with(-ShareDir)->@*) {
-		$self->log_fatal('Unsupported use of a module sharedir') if exists $map->{module};
+		for my $module (keys $map->{module}->%*) {
+			my $expected = "module-share/$module" =~ s/::/-/gr;
+			if ($map->{module}{$module} ne $expected) {
+				$self->log_fatal("Sharedir location for module $module sharedir should be '$expected'");
+			}
+		}
 		$self->log_fatal('Sharedir location must be share/') if defined $map->{dist} and $map->{dist} ne 'share';
 	}
 
@@ -278,7 +284,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny - Build a Build.PL that uses Module::Build:
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 DESCRIPTION
 
